==> ec2-1.131.0-sources.jar: software/amazon/awscdk/services/ec2/LaunchTemplateRequireImdsv2AspectProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for `LaunchTemplateRequireImdsv2Aspect`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.42.0 (build 5f6b62c)", date = "2021-11-07T11:28:29.653Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.LaunchTemplateRequireImdsv2AspectProps")
@software.amazon.jsii.Jsii.Proxy(LaunchTemplateRequireImdsv2AspectProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LaunchTemplateRequireImdsv2AspectProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether warning annotations from this Aspect should be suppressed or not.
     * <p>
     * Default: - false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSuppressWarnings() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LaunchTemplateRequireImdsv2AspectProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LaunchTemplateRequireImdsv2AspectProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LaunchTemplateRequireImdsv2AspectProps> {
        private java.lang.Boolean suppressWarnings;

        /**
         * Sets the value of {@link LaunchTemplateRequireImdsv2AspectProps#getSuppressWarnings}
         * @param suppressWarnings Whether warning annotations from this Aspect should be suppressed or not.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder suppressWarnings(java.lang.Boolean suppressWarnings) {
            this.suppressWarnings = suppressWarnings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LaunchTemplateRequireImdsv2AspectProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LaunchTemplateRequireImdsv2AspectProps build() {
            return new Jsii$Proxy(suppressWarnings);
        }
    }

    /**
     * An implementation for {@link LaunchTemplateRequireImdsv2AspectProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LaunchTemplateRequireImdsv2AspectProps {
        private final java.lang.Boolean suppressWarnings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.suppressWarnings = software.amazon.jsii.Kernel.get(this, "suppressWarnings", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Boolean suppressWarnings) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.suppressWarnings = suppressWarnings;
        }

        @Override
        public final java.lang.Boolean getSuppressWarnings() {
            return this.suppressWarnings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getSuppressWarnings() != null) {
                data.set("suppressWarnings", om.valueToTree(this.getSuppressWarnings()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ec2.LaunchTemplateRequireImdsv2AspectProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LaunchTemplateRequireImdsv2AspectProps.Jsii$Proxy that = (LaunchTemplateRequireImdsv2AspectProps.Jsii$Proxy) o;

            return this.suppressWarnings != null ? this.suppressWarnings.equals(that.suppressWarnings) : that.suppressWarnings == null;
        }

        @Override
        public final int hashCode() {
            int result = this.suppressWarnings != null ? this.suppressWarnings.hashCode() : 0;
            return result;
        }
    }
}

==> ec2-1.133.0-sources.jar: software/amazon/awscdk/services/ec2/LaunchTemplateRequireImdsv2AspectProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for `LaunchTemplateRequireImdsv2Aspect`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ec2.*;
 * LaunchTemplateRequireImdsv2AspectProps launchTemplateRequireImdsv2AspectProps = LaunchTemplateRequireImdsv2AspectProps.builder()
 *         .suppressWarnings(false)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.45.0 (build 61747b6)", date = "2021-11-19T21:31:10.588Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.LaunchTemplateRequireImdsv2AspectProps")
@software.amazon.jsii.Jsii.Proxy(LaunchTemplateRequireImdsv2AspectProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LaunchTemplateRequireImdsv2AspectProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether warning annotations from this Aspect should be suppressed or not.
     * <p>
     * Default: - false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSuppressWarnings() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LaunchTemplateRequireImdsv2AspectProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LaunchTemplateRequireImdsv2AspectProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LaunchTemplateRequireImdsv2AspectProps> {
        java.lang.Boolean suppressWarnings;

        /**
         * Sets the value of {@link LaunchTemplateRequireImdsv2AspectProps#getSuppressWarnings}
         * @param suppressWarnings Whether warning annotations from this Aspect should be suppressed or not.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder suppressWarnings(java.lang.Boolean suppressWarnings) {
            this.suppressWarnings = suppressWarnings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LaunchTemplateRequireImdsv2AspectProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LaunchTemplateRequireImdsv2AspectProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LaunchTemplateRequireImdsv2AspectProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LaunchTemplateRequireImdsv2AspectProps {
        private final java.lang.Boolean suppressWarnings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.suppressWarnings = software.amazon.jsii.Kernel.get(this, "suppressWarnings", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.suppressWarnings = builder.suppressWarnings;
        }

        @Override
        public final java.lang.Boolean getSuppressWarnings() {
            return this.suppressWarnings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getSuppressWarnings() != null) {
                data.set("suppressWarnings", om.valueToTree(this.getSuppressWarnings()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ec2.LaunchTemplateRequireImdsv2AspectProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LaunchTemplateRequireImdsv2AspectProps.Jsii$Proxy that = (LaunchTemplateRequireImdsv2AspectProps.Jsii$Proxy) o;

            return this.suppressWarnings != null ? this.suppressWarnings.equals(that.suppressWarnings) : that.suppressWarnings == null;
        }

        @Override
        public final int hashCode() {
            int result = this.suppressWarnings != null ? this.suppressWarnings.hashCode() : 0;
            return result;
        }
    }
}
